# Changelog

## 1.0.0 (2025-12-10)

Full Changelog: [v0.0.1...v1.0.0](https://github.com/apologist-project/apg-sdk-python/compare/v0.0.1...v1.0.0)

### Chores

* sync repo ([0c93074](https://github.com/apologist-project/apg-sdk-python/commit/0c930746b156721fbc30e55509b37458e176cbed))
* update SDK settings ([c0dc5fe](https://github.com/apologist-project/apg-sdk-python/commit/c0dc5fedacbef620debf66ff530b25bb57a93ad8))
* update SDK settings ([602e44d](https://github.com/apologist-project/apg-sdk-python/commit/602e44d8de902272aa820e6b9e53a62006912ba3))
